Module implementations

Module implementations 

Structs

MinstrobeSahlin2021
An implementation which should produce identical results as the C++ implementation in the repository referenced in the paper here.
RandstrobeSahlin2021
An implementation which should produce identical results as the C++ implementation in the repository referenced in the paper here.

Traits

StrobeHasher
Trait for creating hashes for strobes.
StrobeSelector
Trait for selecting strobes.
StrobemerImplementation
WindowGenerator
Trait for generating windows in which strobes are selected.