Structs
- Minstrobe
Sahlin2021 - An implementation which should produce identical results as the C++ implementation in the repository referenced in the paper here.
- Randstrobe
Sahlin2021 - An implementation which should produce identical results as the C++ implementation in the repository referenced in the paper here.
Traits
- Strobe
Hasher - Trait for creating hashes for strobes.
- Strobe
Selector - Trait for selecting strobes.
- Strobemer
Implementation - Window
Generator - Trait for generating windows in which strobes are selected.